@@ -38,8 +38,11 @@
 
 #include "intel_batchbuffer.h"
 
+#define DRIVER_ANY 0x1
+#define DRIVER_INTEL (0x1 << 1)
+
 #ifdef ANDROID
-#ifndef HAVE_MMAP64
+#if (!(defined HAVE_MMAP64)) && (!(defined __x86_64__))
 extern void*  __mmap2(void *, size_t, int, int, int, off_t);
 
 /* mmap64 is a recent addition to bionic and not available in all android builds. */
@@ -71,8 +74,10 @@ static inline void *igt_mmap64(void *addr, size_t length, int prot, int flags,
 #define ALIGN(v, a) (((v) + (a)-1) & ~((a)-1))
 
 int drm_get_card(void);
-int drm_open_any(void);
-int drm_open_any_render(void);
+int drm_open_driver(int chipset);
+int drm_open_driver_master(int chipset);
+int drm_open_driver_render(int chipset);
+int __drm_open_driver(int chipset);
 
 void gem_quiescent_gpu(int fd);
 
