@@ -55,6 +55,7 @@
 #include <time.h>
 #include <ctype.h>
 #include <limits.h>
+#include <locale.h>
 
 #include "drmtest.h"
 #include "intel_chipset.h"
@@ -73,8 +74,8 @@
 /**
  * SECTION:igt_core
  * @short_description: Core i-g-t testing support
- * @title: i-g-t core
- * @include: igt_core.h
+ * @title: Core
+ * @include: igt.h
  *
  * This library implements the core of the i-g-t test support infrastructure.
  * Main features are the subtest enumeration, cmdline option parsing helpers for
@@ -220,6 +221,7 @@ static const char *in_subtest = NULL;
 static struct timespec subtest_time;
 static bool in_fixture = false;
 static bool test_with_subtests = false;
+static bool in_atexit_handler = false;
 static enum {
 	CONT = 0, SKIP, FAIL
 } skip_subtests_henceforth = CONT;
@@ -522,6 +524,9 @@ static int common_init(int *argc, char **argv,
 	int ret = 0;
 	char *env = getenv("IGT_LOG_LEVEL");
 
+	if (isatty(STDOUT_FILENO))
+		setlocale(LC_ALL, "");
+
 	if (env) {
 		if (strcmp(env, "debug") == 0)
 			igt_log_level = IGT_LOG_DEBUG;
@@ -686,7 +691,7 @@ out:
  * @extra_opt_handler: handler for the additional options
  * @handler_data: user data given to @extra_opt_handler when invoked
  *
- * This function handles the subtest related cmdline options and allows an
+ * This function handles the subtest related command line options and allows an
  * arbitrary set of additional options. This is useful for tests which have
  * additional knobs to tune when run manually like the number of rounds execute
  * or the size of the allocated buffer objects.
@@ -825,6 +830,8 @@ static void exit_subtest(const char *result)
 	elapsed += (now.tv_nsec - subtest_time.tv_nsec) * 1e-9;
 
 	printf("Subtest %s: %s (%.3fs)\n", in_subtest, result, elapsed);
+	fflush(stdout);
+
 	in_subtest = NULL;
 	siglongjmp(igt_subtest_jmpbuf, 1);
 }
@@ -939,6 +946,11 @@ void igt_fail(int exitcode)
 
 	igt_debug_wait_for_keypress("failure");
 
+	/* Exit immediately if the test is already exiting and igt_fail is
+	 * called. This can happen if an igt_assert fails in an exit handler */
+	if (in_atexit_handler)
+		_exit(IGT_EXIT_FAILURE);
+
 	if (!failed_one)
 		igt_exitcode = exitcode;
 
@@ -1404,6 +1416,8 @@ static void call_exit_handlers(int sig)
 
 static void igt_atexit_handler(void)
 {
+	in_atexit_handler = true;
+
 	restore_all_sig_handler();
 
 	if (!exit_handler_disabled)
@@ -1626,7 +1640,7 @@ void igt_skip_on_simulation(void)
  * This is the generic structured logging helper function. i-g-t testcase should
  * output all normal message to stdout. Warning level message should be printed
  * to stderr and the test runner should treat this as an intermediate result
- * between SUCESS and FAILURE.
+ * between SUCCESS and FAILURE.
  *
  * The log level can be set through the IGT_LOG_LEVEL environment variable with
  * values "debug", "info", "warn", "critical" and "none". By default verbose
@@ -1734,9 +1748,13 @@ out:
 	free(line);
 }
 
+static const char *timeout_op;
 static void igt_alarm_handler(int signal)
 {
-	igt_info("Timed out\n");
+	if (timeout_op)
+		igt_info("Timed out: %s\n", timeout_op);
+	else
+		igt_info("Timed out\n");
 
 	/* exit with failure status */
 	igt_fail(IGT_EXIT_FAILURE);
@@ -1745,6 +1763,7 @@ static void igt_alarm_handler(int signal)
 /**
  * igt_set_timeout:
  * @seconds: number of seconds before timeout
+ * @op: Optional string to explain what operation has timed out in the debug log
  *
  * Fail a test and exit with #IGT_EXIT_FAILURE status after the specified
  * number of seconds have elapsed. If the current test has subtests and the
@@ -1752,9 +1771,11 @@ static void igt_alarm_handler(int signal)
  * marked as failed.
  *
  * Any previous timer is cancelled and no timeout is scheduled if @seconds is
- * zero.
+ * zero. But for clarity the timeout set with this function should be cleared
+ * with igt_reset_timeout().
  */
-void igt_set_timeout(unsigned int seconds)
+void igt_set_timeout(unsigned int seconds,
+		     const char *op)
 {
 	struct sigaction sa;
 
@@ -1762,6 +1783,8 @@ void igt_set_timeout(unsigned int seconds)
 	sigemptyset(&sa.sa_mask);
 	sa.sa_flags = 0;
 
+	timeout_op = op;
+
 	if (seconds == 0)
 		sigaction(SIGALRM, NULL, NULL);
 	else
@@ -1770,6 +1793,17 @@ void igt_set_timeout(unsigned int seconds)
 	alarm(seconds);
 }
 
+/**
+ * igt_reset_timeout:
+ *
+ * This function resets a timeout set by igt_set_timeout() and disables any
+ * timer set up by the former function.
+ */
+void igt_reset_timeout(void)
+{
+	igt_set_timeout(0, NULL);
+}
+
 FILE *__igt_fopen_data(const char* igt_srcdir, const char* igt_datadir,
 		       const char* filename)
 {
