@@ -42,8 +42,8 @@
 /**
  * SECTION:igt_debugfs
  * @short_description: Support code for debugfs features
- * @title: i-g-t debugfs
- * @include: igt_debugfs.h
+ * @title: debugfs
+ * @include: igt.h
  *
  * This library provides helpers to access debugfs features. On top of some
  * basic functions to access debugfs files with e.g. igt_debugfs_open() it also
@@ -71,11 +71,11 @@
  *
  * This covers the miscellaneous debugfs interface wrappers:
  *
- * - drm/i915 supports interfaces to evict certain clases of gem buffer objects,
- *   see igt_drop_caches_set().
+ * - drm/i915 supports interfaces to evict certain classes of gem buffer
+ *   objects, see igt_drop_caches_set().
  *
  * - drm/i915 supports an interface to disable prefaulting, useful to test
- *   slowpaths in ioctls. See igt_disable_prefault().
+ *   slow paths in ioctls. See igt_disable_prefault().
  */
 
 /*
@@ -143,7 +143,7 @@ static igt_debugfs_t *__igt_debugfs_singleton(void)
  * @mode: mode bits as used by open()
  *
  * This opens a debugfs file as a Unix file descriptor. The filename should be
- * relative to the drm device's root, i.e without "drm/<minor>".
+ * relative to the drm device's root, i.e. without "drm/<minor>".
  *
  * Returns:
  * The Unix file descriptor for the debugfs file or -1 if that didn't work out.
@@ -166,7 +166,7 @@ int igt_debugfs_open(const char *filename, int mode)
  * @mode: mode string as used by fopen()
  *
  * This opens a debugfs file as a libc FILE. The filename should be
- * relative to the drm device's root, i.e without "drm/<minor>".
+ * relative to the drm device's root, i.e. without "drm/<minor>".
  *
  * Returns:
  * The libc FILE pointer for the debugfs file or NULL if that didn't work out.
@@ -185,6 +185,33 @@ FILE *igt_debugfs_fopen(const char *filename,
 	return fopen(buf, mode);
 }
 
+/**
+ * __igt_debugfs_read:
+ * @filename: file name
+ * @buf: buffer where the contents will be stored, allocated by the caller
+ * @buf_size: size of the buffer
+ *
+ * This function opens the debugfs file, reads it, stores the content in the
+ * provided buffer, then closes the file. Users should make sure that the buffer
+ * provided is big enough to fit the whole file, plus one byte.
+ */
+void __igt_debugfs_read(const char *filename, char *buf, int buf_size)
+{
+	FILE *file;
+	size_t n_read;
+
+	file = igt_debugfs_fopen(filename, "r");
+	igt_assert(file);
+
+	n_read = fread(buf, 1, buf_size - 1, file);
+	igt_assert(n_read > 0);
+	igt_assert(feof(file));
+
+	buf[n_read] = '\0';
+
+	igt_assert(fclose(file) == 0);
+}
+
 /*
  * Pipe CRC
  */
@@ -436,9 +463,9 @@ static bool read_one_crc(igt_pipe_crc_t *pipe_crc, igt_crc_t *out)
 	ssize_t bytes_read;
 	char buf[pipe_crc->buffer_len];
 
-	igt_set_timeout(5);
+	igt_set_timeout(5, "CRC reading");
 	bytes_read = read(pipe_crc->crc_fd, &buf, pipe_crc->line_len);
-	igt_set_timeout(0);
+	igt_reset_timeout();
 
 	igt_assert_eq(bytes_read, pipe_crc->line_len);
 	buf[bytes_read] = '\0';
