@@ -26,6 +26,7 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/ioctl.h>
 #include <fcntl.h>
 
 #include "drmtest.h"
@@ -39,14 +40,28 @@
 /**
  * SECTION:igt_gt
  * @short_description: GT support library
- * @title: i-g-t gt
- * @include: igt_gt.h
+ * @title: GT
+ * @include: igt.h
  *
  * This library provides various auxiliary helper functions to handle general
  * interactions with the GT like forcewake handling, injecting hangs or stopping
  * engines.
  */
 
+static bool has_gpu_reset(int fd)
+{
+	struct drm_i915_getparam gp;
+	int val = 0;
+
+	memset(&gp, 0, sizeof(gp));
+	gp.param = 35; /* HAS_GPU_RESET */
+	gp.value = &val;
+
+	if (ioctl(fd, DRM_IOCTL_I915_GETPARAM, &gp))
+		return intel_gen(intel_get_drm_devid(fd)) >= 5;
+
+	return val > 0;
+}
 
 /**
  * igt_require_hang_ring:
@@ -60,7 +75,7 @@
 void igt_require_hang_ring(int fd, int ring)
 {
 	gem_context_require_ban_period(fd);
-	igt_require(intel_gen(intel_get_drm_devid(fd)) >= 5);
+	igt_require(has_gpu_reset(fd));
 }
 
 /**
@@ -185,7 +200,7 @@ int igt_fork_hang_helper(void)
 	if (igt_only_list_subtests())
 		return 1;
 
-	fd = drm_open_any();
+	fd = drm_open_driver(DRIVER_INTEL);
 	if (fd == -1)
 		return 0;
 
