@@ -112,7 +112,7 @@ intel_get_avail_ram_mb(void)
 
 	retval = sysinf.freeram;
 	retval *= sysinf.mem_unit;
-#elif defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES) /* Solaris */
+#elif defined(_SC_PAGESIZE) && defined(_SC_AVPHYS_PAGES) /* Solaris */
 	long pagesize, npages;
 
 	pagesize = sysconf(_SC_PAGESIZE);
@@ -193,14 +193,14 @@ intel_get_total_swap_mb(void)
 }
 
 /**
- * intel_check_memory:
+ * intel_require_memory:
  * @count: number of surfaces that will be created
  * @size: the size in bytes of each surface
- * @mode: a bitfield declaring whether the test will be run in RAM or in SWAP
+ * @mode: a bit field declaring whether the test will be run in RAM or in SWAP
  *
  * Computes the total amount of memory required to allocate @count surfaces,
  * each of @size bytes, and includes an estimate for kernel overhead. It then
- * queries the kernel for the avilable amount of memory on the system (either
+ * queries the kernel for the available amount of memory on the system (either
  * RAM and/or SWAP depending upon @mode) and determines whether there is
  * sufficient to run the test.
  *
@@ -209,11 +209,13 @@ intel_get_total_swap_mb(void)
  * for their tests. oom-killer tests should only run if this reports that
  * there is not enough RAM + SWAP!
  *
- * Returns:
- * Whether the estimated amount of memory required for the objects
- * fits in the available memory on the system.
+ * If there is not enough RAM this function calls igt_skip with an appropriate
+ * message. It only ever returns if the requirement is fulfilled. This function
+ * also causes the test to be skipped automatically on simulation under the
+ * assumption that any test that needs to check for memory requirements is a
+ * thrashing test unsuitable for slow simulated systems.
  */
-bool intel_check_memory(uint32_t count, uint32_t size, unsigned mode)
+void intel_require_memory(uint32_t count, uint64_t size, unsigned mode)
 {
 /* rough estimate of how many bytes the kernel requires to track each object */
 #define KERNEL_BO_OVERHEAD 512
@@ -223,8 +225,8 @@ bool intel_check_memory(uint32_t count, uint32_t size, unsigned mode)
 	required *= size + KERNEL_BO_OVERHEAD;
 	required = ALIGN(required, 4096);
 
-	igt_debug("Checking %u surfaces of size %u bytes (total %llu) against %s%s\n",
-		  count, size, (long long)required,
+	igt_debug("Checking %'u surfaces of size %'llu bytes (total %'llu) against %s%s\n",
+		  count, (long long)size, (long long)required,
 		  mode & (CHECK_RAM | CHECK_SWAP) ? "RAM" : "",
 		  mode & CHECK_SWAP ? " + swap": "");
 
@@ -235,19 +237,15 @@ bool intel_check_memory(uint32_t count, uint32_t size, unsigned mode)
 		total += intel_get_total_swap_mb();
 	total *= 1024 * 1024;
 
-	if (total <= required) {
-		igt_log(IGT_LOG_INFO,
-			"Estimated that we need %llu bytes for the test, but only have %llu bytes available (%s%s)\n",
-			(long long)required, (long long)total,
-			mode & (CHECK_RAM | CHECK_SWAP) ? "RAM" : "",
-			mode & CHECK_SWAP ? " + swap": "");
-		return 0;
-	}
+	igt_skip_on_f(total <= required,
+		      "Estimated that we need %'llu bytes for the test, but only have %'llu bytes available (%s%s)\n",
+		      (long long)required, (long long)total,
+		      mode & (CHECK_RAM | CHECK_SWAP) ? "RAM" : "",
+		      mode & CHECK_SWAP ? " + swap": "");
 
-	return 1;
+	igt_skip_on_simulation();
 }
 
-
 void
 intel_purge_vm_caches(void)
 {
@@ -257,7 +255,7 @@ intel_purge_vm_caches(void)
 	if (fd < 0)
 		return;
 
-	write(fd, "3\n", 2);
+	igt_assert_eq(write(fd, "3\n", 2), 2);
 	close(fd);
 }
 
