@@ -25,6 +25,7 @@
  *
  */
 
+#include "igt.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
@@ -32,9 +33,6 @@
 #include <fcntl.h>
 #include <limits.h>
 
-#include "drmtest.h"
-#include "ioctl_wrappers.h"
-#include "igt_aux.h"
 
 
 #define FD_ARR_SZ 100
@@ -56,7 +54,7 @@ igt_simple_main
 	rlim.rlim_max = nofile_rlim;
 	igt_assert(setrlimit(RLIMIT_NOFILE, &rlim) == 0);
 
-	fd = drm_open_any();
+	fd = drm_open_driver(DRIVER_INTEL);
 
 	igt_assert(open("/dev/null", O_RDONLY) >= 0);
 
