@@ -30,6 +30,7 @@
 #include "config.h"
 #endif
 
+#include "igt.h"
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -41,8 +42,6 @@
 #include <sys/ioctl.h>
 #include <pthread.h>
 #include "drm.h"
-#include "ioctl_wrappers.h"
-#include "drmtest.h"
 
 #define OBJECT_SIZE (128*1024) /* restricted to 1MiB alignment on i915 fences */
 
@@ -62,13 +61,13 @@ struct test {
 static void *
 bo_create (int fd, int tiling)
 {
+	uint32_t handle;
 	void *ptr;
-	int handle;
 
 	handle = gem_create(fd, OBJECT_SIZE);
 
 	/* dirty cpu caches a bit ... */
-	ptr = gem_mmap__cpu(fd, handle, OBJECT_SIZE, PROT_READ | PROT_WRITE);
+	ptr = gem_mmap__cpu(fd, handle, 0, OBJECT_SIZE, PROT_READ | PROT_WRITE);
 	igt_assert(ptr);
 	memset(ptr, 0, OBJECT_SIZE);
 	munmap(ptr, OBJECT_SIZE);
@@ -78,8 +77,8 @@ bo_create (int fd, int tiling)
 	ptr = gem_mmap(fd, handle, OBJECT_SIZE, PROT_READ | PROT_WRITE);
 	igt_assert(ptr);
 
-	/* XXX: mmap_gtt pulls the bo into the GTT read domain. */
-	gem_sync(fd, handle);
+	gem_set_domain(fd, handle, I915_GEM_DOMAIN_GTT, I915_GEM_DOMAIN_GTT);
+	gem_close(fd, handle);
 
 	return ptr;
 }
@@ -100,6 +99,9 @@ bo_copy (void *_arg)
 		sched_yield ();
 	}
 
+	munmap(a, OBJECT_SIZE);
+	munmap(b, OBJECT_SIZE);
+
 	return NULL;
 }
 
@@ -114,7 +116,7 @@ _bo_write_verify(struct test *t)
 	const char *tile_str[] = { "none", "x", "y" };
 
 	igt_assert(t->tiling >= 0 && t->tiling <= I915_TILING_Y);
-	igt_assert(t->num_surfaces > 0);
+	igt_assert_lt(0, t->num_surfaces);
 
 	s = calloc(sizeof(*s), t->num_surfaces);
 	igt_assert(s);
@@ -166,12 +168,12 @@ static int run_test(int threads_per_fence, void *f, int tiling,
 	pthread_t *threads;
 	int n, num_fences, num_threads;
 
-	t.fd = drm_open_any();
+	t.fd = drm_open_driver(DRIVER_INTEL);
 	t.tiling = tiling;
 	t.num_surfaces = surfaces_per_thread;
 
 	num_fences = gem_available_fences(t.fd);
-	igt_assert(num_fences > 0);
+	igt_assert_lt(0, num_fences);
 
 	num_threads = threads_per_fence * num_fences;
 
@@ -188,6 +190,8 @@ static int run_test(int threads_per_fence, void *f, int tiling,
 
 		for (n = 0; n < num_threads; n++)
 			pthread_join (threads[n], NULL);
+
+		free(threads);
 	} else {
 		void *(*func)(void *) = f;
 		igt_assert(func(&t) == (void *)0);
