@@ -25,6 +25,7 @@
  *
  */
 
+#include "igt.h"
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,8 +36,9 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include "drm.h"
-#include "ioctl_wrappers.h"
-#include "drmtest.h"
+
+IGT_TEST_DESCRIPTION("Checks whether the kernel handles mmap offset exhaustion"
+		     " correctly.");
 
 #define OBJECT_SIZE (1024*1024)
 
@@ -79,7 +81,7 @@ igt_simple_main
 
 	igt_skip_on_simulation();
 
-	fd = drm_open_any();
+	fd = drm_open_driver(DRIVER_INTEL);
 
 	/* we have 32bit of address space, so try to fit one MB more
 	 * than that. */
