@@ -28,6 +28,7 @@
  *
  */
 
+#include "igt.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -43,10 +44,8 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include "drm.h"
-#include "ioctl_wrappers.h"
-#include "intel_chipset.h"
-#include "drmtest.h"
-#include "intel_io.h"
+
+IGT_TEST_DESCRIPTION("Check that kernel relocation overflows are caught.");
 
 /*
  * Testcase: Kernel relocation overflows are caught.
@@ -327,7 +326,7 @@ igt_main
 		int ring;
 		uint32_t batch_data [2] = { MI_NOOP, MI_BATCH_BUFFER_END };
 
-		fd = drm_open_any();
+		fd = drm_open_driver(DRIVER_INTEL);
 
 		devid = intel_get_drm_devid(fd);
 
