@@ -31,6 +31,7 @@
  * catching failure to manage the ring properly near full.
  */
 
+#include "igt.h"
 #include <stdbool.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -43,11 +44,6 @@
 
 #include <drm.h>
 
-#include "ioctl_wrappers.h"
-#include "drmtest.h"
-#include "intel_chipset.h"
-#include "intel_io.h"
-#include "igt_aux.h"
 
 struct bo {
 	const char *ring;
@@ -55,6 +51,7 @@ struct bo {
 };
 
 static const int width = 512, height = 512;
+int fd;
 
 static void create_bo(drm_intel_bufmgr *bufmgr,
 		      struct bo *b,
@@ -88,7 +85,10 @@ static int check_bo(struct bo *b)
 	const uint32_t *map;
 	int i, fails = 0;
 
-	drm_intel_bo_map(b->dst, false);
+	igt_debug("verifying\n");
+
+	do_or_die(drm_intel_bo_map(b->dst, false));
+
 	map = b->dst->virtual;
 	for (i = 0; i < width*height; i++) {
 		if (map[i] != i && ++fails <= 9) {
@@ -111,17 +111,17 @@ static void destroy_bo(struct bo *b)
 	drm_intel_bo_unreference(b->dst);
 }
 
-static int check_ring(drm_intel_bufmgr *bufmgr,
-		      struct intel_batchbuffer *batch,
+static void fill_ring(drm_intel_bufmgr *bufmgr,
 		      const char *ring,
 		      igt_render_copyfunc_t copy)
 {
+	struct intel_batchbuffer *batch;
 	struct igt_buf src, tmp, dst;
 	struct bo bo;
-	char output[100];
 	int i;
 
-	snprintf(output, 100, "filling %s ring: ", ring);
+	batch = intel_batchbuffer_alloc(bufmgr, intel_get_drm_devid(fd));
+	igt_assert(batch);
 
 	create_bo(bufmgr, &bo, ring);
 
@@ -154,9 +154,7 @@ static int check_ring(drm_intel_bufmgr *bufmgr,
 		int x = i % width;
 		int y = i / width;
 
-		igt_progress(output, i, width*height);
-
-		igt_assert(y < height);
+		igt_assert_lt(y, height);
 
 		/* Dummy load to fill the ring */
 		copy(batch, NULL, &src, 0, 0, width, height, &tmp, 0, 0);
@@ -165,11 +163,9 @@ static int check_ring(drm_intel_bufmgr *bufmgr,
 	}
 
 	/* verify */
-	igt_info("verifying\n");
-	i = check_bo(&bo);
+	igt_assert_eq(check_bo(&bo), 0);
 	destroy_bo(&bo);
-
-	return i;
+	intel_batchbuffer_free(batch);
 }
 
 static void blt_copy(struct intel_batchbuffer *batch,
@@ -178,58 +174,96 @@ static void blt_copy(struct intel_batchbuffer *batch,
 		     unsigned w, unsigned h,
 		     struct igt_buf *dst, unsigned dst_x, unsigned dst_y)
 {
-	BLIT_COPY_BATCH_START(batch->devid, 0);
+	BLIT_COPY_BATCH_START(0);
 	OUT_BATCH((3 << 24) | /* 32 bits */
 		  (0xcc << 16) | /* copy ROP */
 		  dst->stride);
 	OUT_BATCH((dst_y << 16) | dst_x); /* dst x1,y1 */
 	OUT_BATCH(((dst_y + h) << 16) | (dst_x + w)); /* dst x2,y2 */
-	OUT_RELOC(dst->bo, I915_GEM_DOMAIN_RENDER, I915_GEM_DOMAIN_RENDER, 0);
-	BLIT_RELOC_UDW(batch->devid);
+	OUT_RELOC_FENCED(dst->bo, I915_GEM_DOMAIN_RENDER, I915_GEM_DOMAIN_RENDER, 0);
 	OUT_BATCH((src_y << 16) | src_x); /* src x1,y1 */
 	OUT_BATCH(src->stride);
-	OUT_RELOC(src->bo, I915_GEM_DOMAIN_RENDER, 0, 0);
-	BLIT_RELOC_UDW(batch->devid);
+	OUT_RELOC_FENCED(src->bo, I915_GEM_DOMAIN_RENDER, 0, 0);
 	ADVANCE_BATCH();
 
 	intel_batchbuffer_flush(batch);
 }
 
-drm_intel_bufmgr *bufmgr;
-struct intel_batchbuffer *batch;
-int fd;
+static void run_test(int ring, bool interruptible, int nchild) {
+	drm_intel_bufmgr *bufmgr;
+	igt_render_copyfunc_t copy;
+	const char* ring_name;
+
+	bufmgr = drm_intel_bufmgr_gem_init(fd, 4096);
+	igt_assert(bufmgr);
+	drm_intel_bufmgr_gem_enable_reuse(bufmgr);
+
+	if (ring == I915_EXEC_RENDER) {
+		copy = igt_get_render_copyfunc(intel_get_drm_devid(fd));
+		ring_name = "render";
+	} else if (ring == I915_EXEC_BLT) {
+		copy = blt_copy;
+		ring_name = "blt";
+	} else {
+		igt_fail_on_f(true, "Unsupported ring.");
+	}
+
+	/* Not all platforms have dedicated render ring. */
+	igt_require(copy);
+
+	if (interruptible) {
+		igt_fork_signal_helper();
+	}
+
+	if (nchild) {
+		igt_fork(child, nchild) {
+			fill_ring(bufmgr, ring_name, copy);
+		}
+		igt_waitchildren();
+	} else {
+		fill_ring(bufmgr, ring_name, copy);
+	}
+
+	if (interruptible) {
+		igt_stop_signal_helper();
+	}
+
+	drm_intel_bufmgr_destroy(bufmgr);
+}
 
 igt_main
 {
 	igt_skip_on_simulation();
 
 	igt_fixture {
-		fd = drm_open_any();
-
-		bufmgr = drm_intel_bufmgr_gem_init(fd, 4096);
-		drm_intel_bufmgr_gem_enable_reuse(bufmgr);
-		batch = intel_batchbuffer_alloc(bufmgr, intel_get_drm_devid(fd));
+		fd = drm_open_driver(DRIVER_INTEL);
 	}
 
 	igt_subtest("blitter")
-		check_ring(bufmgr, batch, "blt", blt_copy);
+		run_test(I915_EXEC_BLT, false, 0);
 
-	/* Strictly only required on architectures with a separate BLT ring,
-	 * but lets stress everybody.
-	 */
-	igt_subtest("render") {
-		igt_render_copyfunc_t copy;
+	igt_subtest("render")
+		run_test(I915_EXEC_RENDER, false, 0);
 
-		copy = igt_get_render_copyfunc(batch->devid);
-		igt_require(copy);
+	igt_subtest("blitter-interruptible")
+		run_test(I915_EXEC_BLT, true, 0);
 
-		check_ring(bufmgr, batch, "render", copy);
-	}
+	igt_subtest("render-interruptible")
+		run_test(I915_EXEC_RENDER, true, 0);
+
+	igt_subtest("blitter-forked-1")
+		run_test(I915_EXEC_BLT, false, 1);
+
+	igt_subtest("render-forked-1")
+		run_test(I915_EXEC_RENDER, false, 1);
+
+	igt_subtest("blitter-forked-4")
+		run_test(I915_EXEC_BLT, false, 4);
+
+	igt_subtest("render-forked-4")
+		run_test(I915_EXEC_RENDER, false, 4);
 
 	igt_fixture {
-		intel_batchbuffer_free(batch);
-		drm_intel_bufmgr_destroy(bufmgr);
-
 		close(fd);
 	}
 }
