@@ -25,6 +25,7 @@
  *
  */
 
+#include "igt.h"
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,9 +36,8 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include "drm.h"
-#include "i915_drm.h"
-#include "drmtest.h"
-#include "intel_gpu_tools.h"
+
+IGT_TEST_DESCRIPTION("Check set_tiling vs gtt mmap coherency.");
 
 #define OBJECT_SIZE (1024*1024)
 #define TEST_STRIDE (1024*4)
@@ -58,7 +58,7 @@ igt_simple_main
 
 	igt_skip_on_simulation();
 
-	fd = drm_open_any();
+	fd = drm_open_driver(DRIVER_INTEL);
 
 	if (IS_GEN2(intel_get_drm_devid(fd)))
 		tile_height = 16;
@@ -76,7 +76,7 @@ igt_simple_main
 
 	gem_set_tiling(fd, handle, I915_TILING_X, TEST_STRIDE);
 
-	printf("testing untiled->tiled\n");
+	igt_info("testing untiled->tiled\n");
 	tiling_changed = false;
 	gem_set_domain(fd, handle, I915_GEM_DOMAIN_GTT, 0);
 	/* Too lazy to check for the correct tiling, and impossible anyway on
@@ -92,7 +92,7 @@ igt_simple_main
 
 	gem_set_tiling(fd, handle, I915_TILING_X, TEST_STRIDE*2);
 
-	printf("testing tiled->tiled\n");
+	igt_info("testing tiled->tiled\n");
 	gem_set_domain(fd, handle, I915_GEM_DOMAIN_GTT, 0);
 	for (i = 0; i < OBJECT_SIZE/4; i++) {
 		int tile_row = i / (TEST_STRIDE * tile_height / 4);
@@ -104,13 +104,11 @@ igt_simple_main
 			+ half*tile_height + ofs;
 		uint32_t val = data[data_i];
 
-		if (ptr[i] != val) {
-			printf("mismatch at %i, row=%i, half=%i, ofs=%i\n",
-			       i, row, half, ofs);
-			printf("read: 0x%08x, expected: 0x%08x\n",
-			       ptr[i], val);
-			igt_assert(0);
-		}
+		igt_assert_f(ptr[i] == val,
+			     "mismatch at %i, row=%i, half=%i, ofs=%i, "
+			     "read: 0x%08x, expected: 0x%08x\n",
+			     i, row, half, ofs,
+			     ptr[i], val);
 
 	}
 
@@ -119,7 +117,7 @@ igt_simple_main
 		ptr[i] = data[i] = i;
 
 	gem_set_tiling(fd, handle, I915_TILING_NONE, 0);
-	printf("testing tiled->untiled\n");
+	igt_info("testing tiled->untiled\n");
 	tiling_changed = false;
 	gem_set_domain(fd, handle, I915_GEM_DOMAIN_GTT, 0);
 	/* Too lazy to check for the correct tiling, and impossible anyway on
