@@ -25,6 +25,7 @@
  *
  */
 
+#include "igt.h"
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,9 +36,8 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include "drm.h"
-#include "ioctl_wrappers.h"
-#include "drmtest.h"
-#include "intel_io.h"
+
+IGT_TEST_DESCRIPTION("Check set_tiling vs pwrite coherency.");
 
 #define OBJECT_SIZE (1024*1024)
 #define TEST_STRIDE (1024*4)
@@ -56,7 +56,7 @@ igt_simple_main
 
 	igt_skip_on_simulation();
 
-	fd = drm_open_any();
+	fd = drm_open_driver(DRIVER_INTEL);
 
 	for (i = 0; i < OBJECT_SIZE/4; i++)
 		data[i] = i;
