@@ -24,6 +24,7 @@
 #include "config.h"
 #endif
 
+#include "igt.h"
 #include <cairo.h>
 #include <errno.h>
 #include <stdint.h>
@@ -31,11 +32,7 @@
 #include <string.h>
 #include <sys/time.h>
 
-#include "drmtest.h"
 #include "intel_bufmgr.h"
-#include "intel_batchbuffer.h"
-#include "intel_io.h"
-#include "igt_kms.h"
 
 #define MAX_CONNECTORS  10
 #define MAX_CRTCS       3
@@ -685,7 +682,7 @@ int main(int argc, char **argv)
 		const char *name;
 	} tests[] = {
 		{ TEST_CLONE | TEST_SINGLE_CRTC_CLONE,
-					"clone-single-crtc" },
+					"basic-clone-single-crtc" },
 		{ TEST_INVALID | TEST_CLONE | TEST_SINGLE_CRTC_CLONE,
 					"invalid-clone-single-crtc" },
 		{ TEST_INVALID | TEST_CLONE | TEST_EXCLUSIVE_CRTC_CLONE,
@@ -710,7 +707,7 @@ int main(int argc, char **argv)
 		     "only one of -d and -t is accepted\n");
 
 	igt_fixture {
-		drm_fd = drm_open_any_master();
+		drm_fd = drm_open_driver_master(DRIVER_INTEL);
 		if (!dry_run)
 			kmstest_set_vt_graphics_mode();
 
