@@ -26,14 +26,13 @@
  */
 
 #define _GNU_SOURCE
+#include "igt.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
 
-#include "drmtest.h"
-#include "intel_chipset.h"
 
 #define SLEEP_DURATION 3000 // in milliseconds
 #define CODE_TIME 50 // in microseconfs
@@ -184,9 +183,9 @@ igt_main
 
 	igt_skip_on_simulation();
 
-	/* Use drm_open_any to verify device existence */
+	/* Use drm_open_driver to verify device existence */
 	igt_fixture {
-		fd = drm_open_any();
+		fd = drm_open_driver(DRIVER_INTEL);
 		devid = intel_get_drm_devid(fd);
 		close(fd);
 
